| fda.vi-package | R Documentation |
Implements a variational Expectation-Maximization (VEM) algorithm for smoothing one or multiple functional observations via basis function selection. The algorithm estimates all model parameters simultaneously and automatically, while accounting for within-curve correlation. The approach provides a flexible and computationally efficient framework for smoothing correlated functional data. The algorithm is described in da Cruz, A. C., de Souza, C. P., and Sousa, P. H. (2024). 'Fast Bayesian basis selection for functional data representation with correlated errors.' \Sexpr[results=rd]{tools:::Rd_expr_doi("10.48550/arXiv.2405.20758")}.
Maintainer: Camila de Souza camila.souza@uwo.ca
Authors:
Stephen Kinsey
Ana Carolina da Cruz
Pedro Henrique Toledo Oliveira Sousa
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.